@@ -15,9 +15,9 @@ from translatehtml import translate_html
 from werkzeug.utils import secure_filename
 
 from app import flood, remove_translated_files, security
-from app.language import detect_languages, transliterate
+from app.language import detect_languages, transliterate, improve_translation_formatting
 
-from .api_keys import Database
+from .api_keys import Database, RemoteDatabase
 from .suggestions import Database as SuggestionsDatabase
 
 
@@ -146,7 +146,12 @@ def create_app(args):
     api_keys_db = None
 
     if args.req_limit > 0 or args.api_keys or args.daily_req_limit > 0:
-        api_keys_db = Database() if args.api_keys else None
+        api_keys_db = None
+        if args.api_keys:
+            if args.api_keys_remote:
+                api_keys_db = RemoteDatabase(args.api_keys_remote)
+            else:
+                api_keys_db = Database(args.api_keys_db_path)
 
         from flask_limiter import Limiter
 
@@ -156,6 +161,7 @@ def create_app(args):
             default_limits=get_routes_limits(
                 args.req_limit, args.daily_req_limit, api_keys_db
             ),
+            storage_uri=args.req_limit_storage,
         )
     else:
         from .no_limiter import Limiter
@@ -172,9 +178,6 @@ def create_app(args):
 
             if flood.is_banned(ip):
                 abort(403, description="Too many request limits violations")
-            else:
-                if flood.has_violation(ip):
-                    flood.decrease(ip)
 
             if args.api_keys:
                 ak = get_req_api_key()
@@ -190,9 +193,12 @@ def create_app(args):
                     and api_keys_db.lookup(ak) is None
                     and request.headers.get("Origin") != args.require_api_key_origin
                 ):
+                    description = "Please contact the server operator to get an API key"
+                    if args.get_api_key_link:
+                        description = "Visit %s to get an API key" % args.get_api_key_link
                     abort(
                         403,
-                        description="Please contact the server operator to obtain an API key",
+                        description=description,
                     )
 
             return f(*a, **kw)
@@ -227,6 +233,7 @@ def create_app(args):
             gaId=args.ga_id,
             frontendTimeout=args.frontend_timeout,
             api_keys=args.api_keys,
+            get_api_key_link=args.get_api_key_link,
             web_version=os.environ.get("LT_WEB") is not None,
             version=get_version()
         )
@@ -474,31 +481,15 @@ def create_app(args):
         if text_format not in ["text", "html"]:
             abort(400, description="%s format is not supported" % text_format)
 
-        def improve_translation(source, translation):
-            if source.islower():
-                return translation.lower()
-
-            if source.isupper():
-                return translation.upper()
-
-            if source[0].islower():
-                return translation[0].lower() + translation[1:]
-
-            if source[0].isupper():
-                return translation[0].upper() + translation[1:]
-
-            return translation
-
         try:
             if batch:
                 results = []
                 for idx, text in enumerate(q):
                     translator = src_langs[idx].get_translation(tgt_lang)
-
                     if text_format == "html":
                         translated_text = str(translate_html(translator, text))
                     else:
-                        translated_text = improve_translation(text, translator.translate(
+                        translated_text = improve_translation_formatting(text, translator.translate(
                             transliterate(text, target_lang=source_langs[idx]["language"])))
 
                     results.append(unescape(translated_text))
@@ -521,7 +512,7 @@ def create_app(args):
                 if text_format == "html":
                     translated_text = str(translate_html(translator, q))
                 else:
-                    translated_text = improve_translation(q, translator.translate(
+                    translated_text = improve_translation_formatting(q, translator.translate(
                         transliterate(q, target_lang=source_langs[0]["language"])))
 
                 if source_lang == "auto":
@@ -581,7 +572,7 @@ def create_app(args):
           200:
             description: Translated file
             schema:
-              id: translate
+              id: translate-file
               type: object
               properties:
                 translatedFileUrl:
