@@ -21,7 +21,7 @@ def check_and_install_models(force=False, load_only_lang_codes=None):
         package.update_package_index()
 
         # Load available packages from local package index
-        available_packages = package.load_available_packages()
+        available_packages = package.get_available_packages()
         print("Found %s models" % len(available_packages))
 
         if load_only_lang_codes is not None:
@@ -55,17 +55,17 @@ def check_and_install_models(force=False, load_only_lang_codes=None):
             package.install_from_path(download_path)
 
         # reload installed languages
-        app.language.languages = translate.load_installed_languages()
+        app.language.languages = translate.get_installed_languages()
         print(
             "Loaded support for %s languages (%s models total)!"
-            % (len(translate.load_installed_languages()), len(available_packages))
+            % (len(translate.get_installed_languages()), len(available_packages))
         )
 
 
 def check_and_install_transliteration(force=False):
     # 'en' is not a supported transliteration language
     transliteration_languages = [
-        l.code for l in app.language.languages if l.code != "en"
+        l.code for l in app.language.load_languages() if l.code != "en"
     ]
 
     # check installed
